package com.caimei.mapper;

import com.caimei.model.po.CmMallOrderShareCodePo;
import com.caimei.model.po.PromotionsPo;
import com.caimei.model.po.ShareCodeRecordPo;
import com.caimei.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/3/26
 */
@Mapper
public interface OrderMapper {

    /**
     * 查询
     *
     * @param userId
     * @param orderState
     * @return
     */
    List<OrderVo> findOrderList(@Param("userId") Integer userId, @Param("orderState") Integer orderState, @Param("organizeId") Integer organizeId);

    /**
     * 查询物流详情
     *
     * @param orderId
     * @return
     */
    List<LogisticsBatchVo> findLogistics(Integer orderId);


    /**
     * 查询该主订单下所有子订单
     *
     * @param orderId
     * @return
     */
    List<ShopOrderVo> findAllShopOrder(Integer orderId);

    /**
     * 查询子订单下所有商品
     *
     * @param shopOrderId
     * @return
     */
    List<OrderProductVo> findOrderProduct(Integer shopOrderId);

    /**
     * 查询订单促销信息
     *
     * @param orderPromotionsId
     * @return
     */
    PromotionsPo findOrderPromotionsById(Integer orderPromotionsId);

    /**
     * 查询收款记录
     *
     * @param orderId
     * @return
     */
    List<DiscernReceiptVo> findDiscernReceipt(Integer orderId);

    /**
     * 查询是否有过线下支付,订单款
     *
     * @param orderId
     * @return
     */
    DiscernReceiptVo findOfflinePayment(Integer orderId);

    /**
     * 查询订单收货地址
     *
     * @param orderId
     * @return
     */
    UserInfoVo findUserInfo(Integer orderId);

    /**
     * 查询订单信息
     *
     * @param orderId
     * @return
     */
    OrderVo findOrder(Integer orderId);

    /**
     * 查询已退货数量
     *
     * @param shopOrderId
     * @param productId
     * @return
     */
    Integer returnedPurchase(@Param("shopOrderId") Integer shopOrderId, @Param("productId") Integer productId);

    /**
     * 查询已取消发货数量
     *
     * @param shopOrderId
     * @param productId
     * @return
     */
    Integer actualCancelNum(@Param("shopOrderId") Integer shopOrderId, @Param("productId") Integer productId);

    /**
     * 查询订单发票
     *
     * @param orderId
     * @return
     */
    OrderInvoiceVo getOrderInvoice(Integer orderId);

    /**
     * 查询退款记录
     *
     * @param orderId
     * @return
     */
    List<ReturnedPurchaseVo> findReturnedPurchase(Integer orderId);

    /**
     * 查询批次物流信息
     *
     * @param shopOrderId
     * @param batchId
     * @return
     */
    List<LogisticsRecordVo> findLogisticsRecord(@Param("shopOrderId") Integer shopOrderId, @Param("batchId") Long batchId);

    /**
     * 物流信息
     *
     * @param batchId
     * @return
     */
    List<LogisticsInformationVo> findLogisticsInfo(Long batchId);

    /**
     * 更新物流状态
     *
     * @param orderId
     */
    void updateLogisticsBatch(Integer orderId);

    /**
     * 更新订单状态
     *
     * @param order
     */
    void updateOrderStatus(OrderVo order);

    /**
     * 查询订单分享信息
     *
     * @param orderId
     * @return
     */
    CmMallOrderShareCodePo queryCode(Integer orderId);

    /**
     * 更新订单分享信息
     *
     * @param orderShareCode
     */
    void updateCode(CmMallOrderShareCodePo orderShareCode);

    /**
     * 删除订单分享信息
     *
     * @param orderId
     */
    void deleteCodeRecord(Integer orderId);

    /**
     * 保存订单分享信息
     *
     * @param orderShareCode
     */
    void insertCode(CmMallOrderShareCodePo orderShareCode);


    /**
     * 查询被分享人信息
     *
     * @param openid
     * @param orderId
     * @return
     */
    ShareCodeRecordPo findShareCodeRecord(@Param("openid") String openid, @Param("orderId") Integer orderId);

    /**
     * 保存被分享人信息
     *
     * @param codeRecord
     */
    void insertShareCodeRecord(ShareCodeRecordPo codeRecord);
}
